@@ -15,7 +15,7 @@ has migrations      => sub {
 };
 has url             => sub { Mojo::MySQL5::URL->new('mysql:///test') };
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub db {
   my $self = shift;
@@ -94,7 +94,8 @@ Mojo::MySQL5 - Pure-Perl non-blocking I/O MySQL Connector
 
   # Create a table
   my $mysql = Mojo::MySQL5->new('mysql://username@/test');
-  $mysql->db->query('create table names (id integer auto_increment primary key, name text)');
+  $mysql->db->query(
+    'create table names (id integer auto_increment primary key, name text)');
 
   # Insert a few rows
   my $db = $mysql->db;
@@ -224,23 +225,24 @@ easily.
 =head2 url
 
   my $url = $mysql->url;
-  $url  = $mysql->url(Mojo::MySQL5::URL->new('mysql://user@host/test?connect_timeout=0'));
+  $url  = $mysql->url(
+    Mojo::MySQL5::URL->new('mysql://user@host/test?connect_timeout=0'));
 
 Connection L<URL|Mojo::MySQL5::URL>.
 
 =head2 options
 
-Use L<url|"/url">->options.
+Use L<url|/"url">->options.
 
 See L<Mojo::MySQL5::Connection> for list of supported options.
 
 =head2 password
 
-Use L<url|"/url">->password.
+Use L<url|/"url">->password.
 
 =head2 username
 
-Use L<url|"/url">->username.
+Use L<url|/"url">->username.
 
 
 =head1 METHODS
@@ -340,6 +342,8 @@ the terms of the Artistic License version 2.0.
 
 =head1 SEE ALSO
 
+L<https://github.com/harryl/mojo-mysql5>,
+
 L<Mojo::Pg> Async Connector for PostgreSQL using L<DBD::Pg>, L<https://github.com/kraih/mojo-pg>,
 
 L<Mojo::mysql> Async Connector for MySQL using L<DBD::mysql>, L<https://github.com/jhthorsen/mojo-mysql>,
